#!/usr/bin/bash

echo "#####"
echo "Updating Repository Packages"
echo "#####"

# Make sure rpmfusion repos never get removed -- this can happen by accident if migrating between gnome and kde

if [[ ! -e /etc/yum.repos.d/rpmfusion-free.repo ]];then
	sudo dnf install -y rpmfusion-free-release
fi

if [[ ! -e /etc/yum.repos.d/rpmfusion-free-updates.repo ]];then
	sudo dnf install -y rpmfusion-free-release
fi

if [[ ! -e /etc/yum.repos.d/rpmfusion-nonfree.repo ]];then
	sudo dnf install -y rpmfusion-nonfree-release
fi

if [[ ! -e /etc/yum.repos.d/rpmfusion-nonfree-updates.repo ]];then
	sudo dnf install -y rpmfusion-nonfree-release
fi

# Store shasums of fedora and nobara repos so we can check for changes

SHAFEDORA=$(sha256sum /etc/yum.repos.d/fedora.repo)
SHAFEDORAUPDATES=$(sha256sum /etc/yum.repos.d/fedora-updates.repo)
SHAFEDORACISCO=$(sha256sum /etc/yum.repos.d/fedora-cisco-openh264.repo)
SHANOBARA=$(sha256sum /etc/yum.repos.d/nobara.repo)

# Get repo updates first

sudo -S dnf update -y fedora-gpg-keys nobara-gpg-keys --nogpgcheck --refresh
sudo -S dnf update -y rpmfusion-nonfree-release rpmfusion-free-release fedora-repos nobara-repos

# Check against shasums for new repo files
# We don't check against rpmfusion because those should never change.

REFRESH=""
if [[ $SHAFEDORA != $(sha256sum /etc/yum.repos.d/fedora.repo) ]];then
	REFRESH="--refresh"
fi
if [[ $SHAFEDORAUPDATES != $(sha256sum /etc/yum.repos.d/fedora-updates.repo) ]];then
	REFRESH="--refresh"
fi
if [[ $SHAFEDORACISCO != $(sha256sum /etc/yum.repos.d/fedora-cisco-openh264.repo) ]];then
	REFRESH="--refresh"
fi
if [[ $SHANOBARA != $(sha256sum /etc/yum.repos.d/nobara.repo) ]];then
	REFRESH="--refresh"
fi

# Store shasums of welcome app update script so we can check for changes

SHAUPDATE=$(sha256sum /etc/nobara/scripts/nobara-welcome/updater.sh)

# Update the welcome app to check for update script changes

sudo -S dnf update -y nobara-welcome $REFRESH

# If script has been updated, restart it:

if [[ $SHAUPDATE != $(sha256sum /etc/nobara/scripts/nobara-welcome/updater.sh) ]];then
        ScriptLoc=$(readlink -f "$0")
        exec "$ScriptLoc"
fi

MEDIAFIXUP=0
if [[ ! -z $(rpm -qa | grep ffmpeg-libs) ]]; then
	MEDIAFIXUP=1
fi

if [[ ! -z $(rpm -qa | grep libavcodec-freeworld) ]]; then
	if [[ ! -z $(rpm -qa | grep noopenh264) ]]; then
		MEDIAFIXUP=1
	fi
	if [[ -z $(rpm -qa | grep libavcodec-free) ]]; then
		MEDIAFIXUP=1
	fi
fi

if [[ -z $(rpm -qa | grep libavcodec-freeworld) ]]; then
        MEDIAFIXUP=1
fi

if [[ ! -z $(rpm -qa | grep qt5-qtwebengine-freeworld) ]]; then
        MEDIAFIXUP=1
fi

# temporary -- fixup ffmpeg packages before f39 release
if [[ $MEDIAFIXUP == 1 ]]; then
	echo "#####"
	echo "Performing package cleanup before F39 release -- this step is temporary."
	echo "#####"

	# Remove possible troublesome 3rd party codec packages
	sudo rpm -e --nodeps ffmpeg
	sudo rpm -e --nodeps ffmpeg-libs.x86_64
	sudo rpm -e --nodeps ffmpeg-libs.i686
	sudo rpm -e --nodeps libavcodec-freeworld.x86_64
	sudo rpm -e --nodeps libavcodec-freeworld.i686
	sudo rpm -e --nodeps libavdevice.x86_64
	sudo rpm -e --nodeps libavdevice.i686
	sudo rpm -e --nodeps obs-studio-gstreamer-vaapi.x86_64
	sudo rpm -e --nodeps openh264
	sudo dnf remove -y qt5-qtwebengine-freeworld &> /dev/null

	# Remove no longer needed unrar was a dependency for an app that is now available in flatpak
	sudo dnf remove -y unrar &> /dev/null

	# Install fedora shipped ffmpeg
	sudo dnf install -y ffmpeg-free --refresh
	sudo dnf install -y libavcodec-free.x86_64 libavcodec-free.i686
	sudo dnf install -y libavutil-free.x86_64 libavutil-free.i686
	sudo dnf install -y libswresample-free.x86_64 libswresample-free.i686
	sudo dnf install -y libavformat-free.x86_64 libavformat-free.i686
	sudo dnf install -y libpostproc-free.x86_64 libpostproc-free.i686
	sudo dnf install -y libswscale-free.x86_64 libswscale-free.i686
	sudo dnf install -y libavfilter-free.x86_64 libavfilter-free.i686
	sudo dnf install -y libavdevice-free.x86_64 libavdevice-free.i686

	# Remove dummy openh264 stub packages
	sudo rpm -e --nodeps noopenh264.x86_64
	sudo rpm -e --nodeps noopenh264.i686

	# Remove mozilla-openh264 to trigger openh264 dependency on update.
	sudo dnf remove -y mozilla-openh264 &> /dev/null

	# Install multimedia group if it's not installed
	sudo dnf groupinstall -y multimedia --exclude=ffmpeg,ffmpeg-libs,qt5-qtwebengine-freeworld

	# make sure 32 bit libavcodec-freeworld got added too
	if [[ -z $(rpm -qa | grep libavcodec-freeworld | grep i686) ]]; then
        sudo dnf install -y libavcodec-freeworld.i686
	fi
fi

echo "#####"
echo "Performing distribution sync to prevent package update mismatches"
echo "#####"
sudo -S dnf distro-sync -y

echo "#####"
echo "Updating the system"
echo "#####"
sudo -S dnf update -y

if [ -e /etc/nobara/newinstall ]; then
	rm -Rf /etc/nobara/newinstall
fi

